function [g,n] = MakeMatrix(model,ptype,param,DATA,dm,im,varargin)
%MakeMatrix(ptype,param,DATA,dm,im,om) Generate data matrices from data files
%   Kevin Mackie, 2002/01/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: dm - number of DM in summary file
%          im - number of IM in summary file
%          om - (varargin) number of additional IM or DM quantity in summary file
%               if om has 2 entries then we need both T1 and T2 for SDHC
%          model - 0 for PSDA 1 for IDA
%          ptype - 1 for parameter 2 for seismicity
%          param - current parameter group
%          DATA - array of information about group and type
%   OUTPUT: g1->g4->gn (Ax2|3) matrices of data in linear space
%          m - #bins if ptype=1, #parameters if ptype=2

global SUMLOC;

switch SUMLOC
   case 'combo'
      dm=[dm dm+10 dm+19]
	  im=[im im+34 im+55]
   otherwise
      dm=dm*ones(1,length(DATA.vals));
	  im=im*ones(1,length(DATA.vals));
end;

if nargin<7,
   ncols=2;          % only 1 DM and IM
elseif nargin<8,
   ncols=3;          % 2 of one of them has been extracted
   om=varargin{1};
elseif nargin<9,
   ncols=4;          % there is a call for T1 and T2
   om=varargin{1};
   om2=varargin{2};
end;

% Provisions for when there are variable eqks in IDA analysis
if model==0,		% PSDA
   EQKS_PER_BIN=20;
else				% IDA
   EQKS_PER_BIN=20;
end;

tmpfname=strcat(SUMLOC,'_summary.mat');
s=pwd;
filebase=fullfile(s,tmpfname,'f');
% use to specify location of files to use with
% load(filebase+) -ascii

if ptype==1
   GROUPS=DATA.para;
elseif ptype==2			% transpose yields correct groupings
   GROUPS=DATA.para';
else
   disp('Unknown data groups requested in MakeMatrix.m');
end;

% m is #parameters, n is #bins (in parameter mode, reverse if transposed)
[m,n]=size(GROUPS);
obtain=n*EQKS_PER_BIN;

tic;
if model==1,			% IDA
   for i=1:m,
      g{i}.v=zeros(obtain,ncols);
      for j=1:n,
         for eqk=1:EQKS_PER_BIN,
            filename=sprintf('%s%04i0001%02i.mat',filebase,GROUPS(i,j),eqk);
		    identify=sprintf('f%04i0001%02i',GROUPS(i,j),eqk);
		    if ncols==2,
   		       [xvar,yvar]=ReadFile(filename,identify,dm(i),im(i));
		       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar];
		    elseif ncols==3,
		       [xvar,yvar,zvar]=ReadFile(filename,identify,dm(i),im(i),om);
	   	       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar;zvar];
			elseif ncols==4,
		       [xvar,yvar,zvar,zvar2]=ReadFile(filename,identify,dm(i),im(i),om,om2);
	   	       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar;zvar;zvar2];
	        end;
         end;
      end;
   end;
else					% PSDA
   for i=1:m,
      g{i}.v=zeros(obtain,ncols);
      for j=1:n,
         for eqk=1:EQKS_PER_BIN,
            filename=sprintf('%s%04i%04i.mat',filebase,GROUPS(i,j),eqk);
		    identify=sprintf('f%04i%04i',GROUPS(i,j),eqk);
		    if ncols==2,
   		       [xvar,yvar]=ReadFile(filename,identify,dm(i),im(i));
		       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar];
		    elseif ncols==3,
		       [xvar,yvar,zvar]=ReadFile(filename,identify,dm(i),im(i),om);
	   	       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar;zvar];
	        elseif ncols==4,
		       [xvar,yvar,zvar,zvar2]=ReadFile(filename,identify,dm(i),im(i),om,om2);
	   	       g{i}.v( (j-1)*EQKS_PER_BIN+eqk ,: ) = [xvar;yvar;zvar;zvar2];
	        end;
         end;
      end;
   end;
end;
toc;

% look into storing common matrices in a fifo buffer to expedite plotting of
% previously computed quantities
